% Qrlew documentation master file, created by
% sphinx-quickstart on Fri Jun 16 15:42:26 2023.
% You can adapt this file completely to your liking, but it should at least
% contain the root `toctree` directive.

# Qrlew Python API

```{toctree}
---
maxdepth: 2
caption: Contents:
---
api
```

# Dataset
- {doc}`api`
- {doc}`compilation_rules`


## Contributing

To contribute to this code, follow the [instructions](contributing)

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
